@@ -222,6 +222,20 @@ sng_fd_t sangoma_open_tdmapi_span_chan(int span, int chan)
 #endif
 }            
 
+
+sng_fd_t sangoma_open_tdmapi_ctrl(void)
+{
+	int fd=-1;
+
+#if defined(WIN32)
+#warning "sangoma_open_tdmapi_ctrl: Not support on Windows"
+#else
+        fd = open("/dev/wptdm_ctrl", O_RDWR);
+#endif
+
+        return fd;
+}
+
 sng_fd_t sangoma_create_socket_by_name(char *device, char *card) 
 {
 	int span,chan;
@@ -514,6 +528,7 @@ int sangoma_get_full_cfg(sng_fd_t fd, wanpipe_tdm_api_t *tdm_api)
 		return err;
 	}
 
+#if 0
 	printf("TDM API CFG:\n");
 	printf("\thw_tdm_coding:\t%d\n",tdm_api->wp_tdm_cmd.hw_tdm_coding);
 	printf("\tusr_mtu_mru:\t%d\n",tdm_api->wp_tdm_cmd.hw_mtu_mru);
@@ -538,7 +553,8 @@ int sangoma_get_full_cfg(sng_fd_t fd, wanpipe_tdm_api_t *tdm_api)
 	printf("\trx ovr\t%d\ttx idl\t%d\n",
 				tdm_api->wp_tdm_cmd.stats.rx_fifo_errors,
 				tdm_api->wp_tdm_cmd.stats.tx_carrier_errors);
-#endif				
+#endif		
+#endif		
 	
 	return 0;
 }
@@ -808,7 +824,6 @@ int sangoma_tdm_read_event(sng_fd_t fd, wanpipe_tdm_api_t *tdm_api)
 	switch (rx_event->wp_tdm_api_event_type){
 	
 	case WP_TDMAPI_EVENT_RBS:
-		printf("%d: GOT RBS EVENT %p\n",(int)fd,tdm_api->wp_tdm_event.wp_rbs_event);
 		if (tdm_api->wp_tdm_event.wp_rbs_event) {
 			tdm_api->wp_tdm_event.wp_rbs_event(fd,rx_event->wp_tdm_api_event_rbs_bits);
 		}
