@@ -128,14 +128,19 @@ static unsigned char sdla_56k_get_fe_media(sdla_fe_t *fe)
 }
 
 /******************************************************************************
- *				sdla_56k_get_fe_status()	
- *
- * Description:
- * Arguments:	
- * Returns:
- ******************************************************************************
- */
-static int sdla_56k_get_fe_status(sdla_fe_t *fe, unsigned char *status)
+* sdla_56k_get_fe_status()	
+*
+* Description	: Get current FE line state - is it Connected or Disconnected
+*
+* Arguments	: fe - pointer to Front End structure.	
+*		  status - pointer to location where the FE line state will
+*			be stored. 
+*		  notused - ignored 
+*
+* Returns	: always zero.
+*******************************************************************************/
+
+static int sdla_56k_get_fe_status(sdla_fe_t *fe, unsigned char *status, int notused)
 {
 	AFT_FUNC_DEBUG();
 	*status = fe->fe_status;
@@ -488,7 +493,7 @@ static void display_Rx_code_condition(sdla_fe_t* fe)
  ******************************************************************************
  */
 static int 
-sdla_56k_set_lbmode(sdla_fe_t *fe, unsigned char type, unsigned char mode) 
+sdla_56k_set_lbmode(sdla_fe_t *fe, unsigned char mode, unsigned char enable) 
 {
 	
 	//unsigned char loop=BIT_RX_CTRL_DSU_LOOP|BIT_RX_CTRL_CSU_LOOP;
@@ -496,7 +501,7 @@ sdla_56k_set_lbmode(sdla_fe_t *fe, unsigned char type, unsigned char mode)
 	//unsigned char loop=BIT_RX_CTRL_CSU_LOOP;
 	unsigned char loop=0x00;
 
-	if(type==WAN_TE1_PAYLB_MODE){
+	if(mode==WAN_TE1_PAYLB_MODE){
                 loop=BIT_RX_CTRL_DSU_LOOP;
         }else{
                 loop=BIT_RX_CTRL_CSU_LOOP;
@@ -505,7 +510,7 @@ sdla_56k_set_lbmode(sdla_fe_t *fe, unsigned char type, unsigned char mode)
 	WAN_ASSERT(fe->write_fe_reg == NULL);
 	WAN_ASSERT(fe->read_fe_reg == NULL);
 	
-	if (mode == WAN_TE1_ACTIVATE_LB){
+	if (enable == WAN_TE1_LB_ENABLE){
 		WRITE_REG(REG_RX_CTRL, READ_REG(REG_RX_CTRL) | loop);
 			
 		DEBUG_EVENT("%s: %s Diagnostic Digital Loopback mode activated (0x%X).\n",
@@ -538,16 +543,18 @@ sdla_56k_set_lbmode(sdla_fe_t *fe, unsigned char type, unsigned char mode)
 static int sdla_56k_udp(sdla_fe_t *fe, void* pudp_cmd, unsigned char* data)
 {
 	wan_cmd_t	*udp_cmd = (wan_cmd_t*)pudp_cmd;
+	wan_femedia_t	*fe_media;
 	int err;
 
 	AFT_FUNC_DEBUG();
 
 	switch(udp_cmd->wan_cmd_command){
 	case WAN_GET_MEDIA_TYPE:
-		data[0] = (IS_56K_FEMEDIA(fe) ? WAN_MEDIA_56K : 
-						WAN_MEDIA_NONE);
+		fe_media = (wan_femedia_t*)data;
+		memset(fe_media, 0, sizeof(wan_femedia_t));
+		fe_media->media		= WAN_MEDIA_56K;
 		udp_cmd->wan_cmd_return_code = WAN_CMD_OK;
-		udp_cmd->wan_cmd_data_len = sizeof(unsigned char); 
+		udp_cmd->wan_cmd_data_len = sizeof(wan_femedia_t); 
 		break;
 
 	case WAN_FE_GET_STAT:
