@@ -90,7 +90,7 @@
 
 static int sdla_te3_config(void *p_fe);
 static int sdla_te3_unconfig(void *p_fe);
-static int sdla_te3_get_fe_status(sdla_fe_t *fe, unsigned char *status);
+static int sdla_te3_get_fe_status(sdla_fe_t *fe, unsigned char *status, int notused);
 static int sdla_te3_polling(sdla_fe_t *fe);
 static int sdla_ds3_isr(sdla_fe_t *fe);
 static int sdla_e3_isr(sdla_fe_t *fe);
@@ -130,14 +130,18 @@ static unsigned char sdla_te3_get_fe_media(sdla_fe_t *fe)
 }
 
 /******************************************************************************
- *				sdla_te3_get_fe_status()	
- *
- * Description:
- * Arguments:	
- * Returns:
- ******************************************************************************
- */
-static int sdla_te3_get_fe_status(sdla_fe_t *fe, unsigned char *status)
+* sdla_te3_get_fe_status()	
+*
+* Description	: Get current FE line state - is it Connected or Disconnected
+*
+* Arguments	: fe - pointer to Front End structure.	
+*		  status - pointer to location where the FE line state will
+*			be stored. 
+*		  notused - ignored 
+*
+* Returns	: always zero.
+*******************************************************************************/
+static int sdla_te3_get_fe_status(sdla_fe_t *fe, unsigned char *status, int notused)
 {
 	*status = fe->fe_status;
 	return 0;
@@ -780,13 +784,16 @@ static int sdla_te3_udp(sdla_fe_t *fe, void *pudp_cmd, unsigned char *data)
 {
 	sdla_t		*card = (sdla_t*)fe->card;
 	wan_cmd_t	*udp_cmd = (wan_cmd_t*)pudp_cmd;
+	wan_femedia_t	*fe_media;
 	int		err = -EINVAL;
 
 	switch(udp_cmd->wan_cmd_command){
 	case WAN_GET_MEDIA_TYPE:
-		data[0] = fe->fe_cfg.media;
+		fe_media = (wan_femedia_t*)data;
+		memset(fe_media, 0, sizeof(wan_femedia_t));
+		fe_media->media	= fe->fe_cfg.media;
 		udp_cmd->wan_cmd_return_code = WAN_CMD_OK;
-		udp_cmd->wan_cmd_data_len = sizeof(unsigned char); 
+		udp_cmd->wan_cmd_data_len = sizeof(wan_femedia_t); 
 		break;
 
 	case WAN_FE_LB_MODE:
