@@ -277,11 +277,7 @@ sub gen_wanpipe_conf{
 	} elsif ($ss7_option == 2){
                 $wanpipe_conf_template = $self->card->current_dir."/templates/ss7_a100/wanpipe.tdmvoiceapi.a100";
 	}
-
-	if($self->signalling eq 'TDM API'){
-                $wanpipe_conf_template = $self->card->current_dir."/templates/wanpipe.tdm_api.a100";
-	}
-
+	
         $dchan = 0;
 	if(!$is_freebsd){
 		if ($self->signalling  =~ m/PRI/ | $self->signalling  =~ m/SS7/ ){
@@ -300,6 +296,13 @@ sub gen_wanpipe_conf{
 		$te_sig_mode_line= 'TE_SIG_MODE     = '.$te_sig_mode;
 	}
 
+	if($self->signalling eq 'TDM API'){
+                $wanpipe_conf_template = $self->card->current_dir."/templates/wanpipe.tdm_api.a100";
+		#for tdm_api hw_dchan is set by user
+		$dchan = $self->hw_dchan;
+		
+	}
+
 	open(FH, $wanpipe_conf_template) or die "Can't open $wanpipe_conf_template";
 	my $wp_file='';
        	while (<FH>) {
