@@ -79,6 +79,9 @@
  * 			GLOBAL VARIABLES				      *
  *****************************************************************************/
 /* The ft1_lib needs these global variables */
+extern wan_femedia_t	femedia;
+extern char *csudsu_menu_te1_pmc[];
+extern char *csudsu_menu_te1_dm[];
 
 /******************************************************************************
  * 			FUNCTION PROTOTYPES				      *
@@ -168,15 +171,32 @@ char ** AFTget_cmd_menu(char *cmd_name,int *len)
 	int i=0,j=0;
 	char **cmd_menu=NULL;
 	
-	while(gui_cmd_menu_lookup[i].cmd_menu_ptr != NULL){
-		if (strcmp(cmd_name,gui_cmd_menu_lookup[i].cmd_menu_name) == 0){
-			cmd_menu=(char**)gui_cmd_menu_lookup[i].cmd_menu_ptr;
-			while (strcmp(cmd_menu[j],".") != 0){
-				j++;
+	if (strcmp(cmd_name, "csudsu_menu") == 0){
+
+		if (femedia.media == WAN_MEDIA_T1 || femedia.media == WAN_MEDIA_E1){  
+			if (femedia.chip_id == WAN_TE_CHIP_PMC){
+				cmd_menu = csudsu_menu_te1_pmc;
+			}else if (femedia.chip_id == WAN_TE_CHIP_DM){
+				cmd_menu = csudsu_menu_te1_dm;
+			}else{
+				cmd_menu = csudsu_menu;
 			}
-			break;
+		}else{
+			cmd_menu = csudsu_menu;
+		}
+	}else{
+		while(gui_cmd_menu_lookup[i].cmd_menu_ptr != NULL){
+			if (strcmp(cmd_name,gui_cmd_menu_lookup[i].cmd_menu_name) == 0){
+				cmd_menu=(char**)gui_cmd_menu_lookup[i].cmd_menu_ptr;
+				break;
+			}
+			i++;
+		}
+	}
+	if (cmd_menu){
+		while (strcmp(cmd_menu[j],".") != 0){
+			j++;
 		}
-		i++;
 	}
 	*len=j/2;
 	return cmd_menu;
@@ -1310,45 +1330,45 @@ int AFTMain(char *command,int argc, char* argv[])
 			}else if (!strcmp(opt,"lb")){
 				get_lb_modes();
 			}else if (!strcmp(opt,"allb")){
-				set_lb_modes(WAN_TE1_LINELB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LINELB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dllb")){
-				set_lb_modes(WAN_TE1_LINELB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LINELB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"aplb")){
-				set_lb_modes(WAN_TE1_PAYLB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_PAYLB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dplb")){
-				set_lb_modes(WAN_TE1_PAYLB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_PAYLB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"adlb")){
-				set_lb_modes(WAN_TE1_DDLB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_DDLB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"ddlb")){
-				set_lb_modes(WAN_TE1_DDLB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_DDLB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"salb")){
-				set_lb_modes(WAN_TE1_TX_LB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_TX_LB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"sdlb")){
-				set_lb_modes(WAN_TE1_TX_LB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_TX_LB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"alalb")){
-				set_lb_modes(WAN_TE1_LIU_ALB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LIU_ALB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dlalb")){
-				set_lb_modes(WAN_TE1_LIU_ALB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LIU_ALB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"alllb")){
-				set_lb_modes(WAN_TE1_LIU_LLB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LIU_LLB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dlllb")){
-				set_lb_modes(WAN_TE1_LIU_LLB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LIU_LLB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"alrlb")){
-				set_lb_modes(WAN_TE1_LIU_RLB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LIU_RLB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dlrlb")){
-				set_lb_modes(WAN_TE1_LIU_RLB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LIU_RLB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"aldlb")){
-				set_lb_modes(WAN_TE1_LIU_DLB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LIU_DLB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dldlb")){
-				set_lb_modes(WAN_TE1_LIU_DLB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_LIU_DLB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"aflb")){
-				set_lb_modes(WAN_TE1_FR_FLB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_FR_FLB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dflb")){
-				set_lb_modes(WAN_TE1_FR_FLB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_FR_FLB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"afplb")){
-				set_lb_modes(WAN_TE1_FR_PLB_MODE, WAN_TE1_ACTIVATE_LB);
+				set_lb_modes(WAN_TE1_FR_PLB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dfplb")){
-				set_lb_modes(WAN_TE1_FR_PLB_MODE, WAN_TE1_DEACTIVATE_LB);
+				set_lb_modes(WAN_TE1_FR_PLB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"a")){
 				read_te1_56k_stat(0);
 			}else if (!strcmp(opt,"af")){
